@@ -46,7 +46,8 @@ static string native_encoding(
 
 //=== Config ===============================================================
 Config::Config ()
-	: m_config_file()
+	: m_app_name()
+	, m_config_file()
 	, m_od_visible(256)
 	, m_od_cmdline()
 	, m_od_cfgfile()
@@ -73,6 +74,11 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 {
 	try
 	{
+		// get the application's name and let derived classes
+		// handle it
+		m_app_name = path(argv[0]).stem();
+		HandleApplicationName();
+
 		// evaluate command line
 		command_line_parser cp(argc, argv);
 		m_od_cmdline.add(m_od_visible); // a bit tricky
@@ -228,6 +234,10 @@ void Config::Init (int argc, char* argv[]) throw (Xception)
 	CATCH_RETHROW("error in configuration file")
 }
 
+void Config::HandleApplicationName ()
+{
+}
+
 void Config::ModifyCmdLineOptions (parsed_options& po)
 {
 }
@@ -353,6 +363,11 @@ string Config::GetFilenameOption (const string& option) const
 	return string();
 }
 
+const string& Config::GetApplicationName () const
+{
+	return m_app_name;
+}
+
 ptime Config::GetNow () const
 {
 	// in fast mode we need constant value for "now" for getting usable
