@@ -418,6 +418,33 @@ void PocoDatabaseImpl::DeleteCollectionsItems (const ptime& timestamp, const Col
 	CATCH_RETHROW("could not delete collection data")
 }
 
+ptime PocoDatabaseImpl::GetLastRssUpdate (const string& feed) const throw (Xception)
+{
+	try
+	{
+		string t;
+		(*m_pSession) << "select t from TLastRssUpdates where f='" << feed << "';", into(t), now;
+
+		return (t.empty()) ? ptime() : lexical_cast<ptime>(t);
+	}
+	CATCH_RETHROW("could not get last RSS update")
+}
+
+void PocoDatabaseImpl::SetLastRssUpdate (const string& feed, const ptime& timestamp) const throw (Xception)
+{
+	try
+	{
+		string t;
+		(*m_pSession) << "select t from TLastRssUpdates where f='" << feed << "';", into(t), now;
+
+		if (t.empty())
+			(*m_pSession) << "insert into TLastRssUpdates (f,t) values ('" << feed << "','" << lexical_cast<string>(timestamp) << "');", now;
+		else
+			(*m_pSession) << "update TLastRssUpdates set t='" << lexical_cast<string>(timestamp) << "' where f='" << feed << "';", now;
+	}
+	CATCH_RETHROW("could not set last RSS update")
+}
+
 ptime PocoDatabaseImpl::GetYoungestCollectionItemAtAll () const throw (Xception)
 {
 	try
