@@ -722,3 +722,8 @@ void OAuthHttpClient::Request (const string& method, const string& filename, con
 	// request!
 	HttpClient::Request(method, filename, headers, body);
 }
+
+string OAuthHttpClient::GetUniqueFeedIdentifier () const
+{
+	return m_access_token + ',' + m_access_token_secret;
+}
