@@ -1,3 +1,4 @@
+
 // This file is part of the pdr/pdx project.
 // Copyright (C) 2010 Torsten Mueller, Bern, Switzerland
 //
@@ -24,6 +25,8 @@ using namespace boost::program_options;
 using namespace boost::filesystem;
 
 #include "../libpdrx/datatypes.h"
+#include "../libpdrx/xception.h"
+#include "../libpdrx/conversions.h"
 #include "../libpdrx/config.h"
 #include "db.h"
 #include "in_impl.h"
@@ -138,40 +141,26 @@ string InputImpl::ExtractCharsetFromContentType (const string& content_type)
 		return string(); // no charset or not text/plain
 }
 
-void InputImpl::LocalizeMailDate (int dt_zone, ptime& timestamp)
-{
-	// if needed, convert to UTC
-	if (dt_zone != 0)
-	{
-		int diff_hours = dt_zone / 100;
-		int diff_min = dt_zone - diff_hours * 100;
-		timestamp -= time_duration(diff_hours, diff_min, 0, 0);
-	}
-
-	// now localize
-	typedef boost::date_time::c_local_adjustor<ptime> local_adj;
-	timestamp = local_adj::utc_to_local(timestamp);
-}
-
-ptime InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose, Database::CollectionsItems& items) throw (Xception)
+ptime InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose, const set<string>& collections, Database::CollectionsItems& items) throw (Xception)
 {
 	string line(expr);
 
-	static const regex rx_comment("[;#]\\s*(.+)\\s*$");					// #... ;...
+	static const regex rx_comment("[;#](.*)$");						// #... ;...
 	static const regex rx_datetime("([0-9]{1,4})-([0-9]{1,2})-([0-9]{1,2})-([0-9]{1,2})[:]([0-9]{1,2})(?:[:]([0-9]{1,2}))?"); // 2009-02-27-15:27[:59]
 	static const regex rx_time("([0-9]{1,2})[:]([0-9]{1,2})(?:[:]([0-9]{1,2}))?");		// 15:27[:59]
 	static const regex rx_date("([0-9]{1,4})-([0-9]{1,2})-([0-9]{1,2})");			// 2009-02-27
-	static const regex rx_string("\"((?:[^\"]|(?:\"\"))*)\"("RX_COLLECTION_NAME")");	// "..." A-Z a-z _ * + ! ? ^   $ & [ ] { } = ~
+	static const regex rx_string("\"((?:[^\"]|(?:\"\"))*)\"("RX_COLLECTION_NAME")");	// "..."RX_COLLECTION_NAME
 	static const regex rx_ratio("([0-9]+(?:\\.[0-9]+)?)([/%])([0-9]+(?:\\.[0-9]+)?)");	// double[/%]double
-	static const regex rx_numeric("([0-9]+(?:\\.[0-9]+)?)("RX_COLLECTION_NAME")?");		// double [A-Z a-z _ * + ! ? ^   $ & [ ] { } = ~]
+	static const regex rx_numeric("([0-9]+(?:\\.[0-9]+)?)("RX_COLLECTION_NAME")?");		// doubleRX_COLLECTION_NAME
 
 	smatch mr;
 
 	// try to find a comment
-	any comment;
+	string comment;
 	if (regex_search(line, mr, rx_comment, boost::match_not_dot_newline))
 	{
-		comment = string(mr[1]);
+		comment = mr[1];
+		trim(comment);
 		line.erase(mr.position(), mr.length());
 	}
 
@@ -221,7 +210,7 @@ ptime InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose
 	{
 		// date is syntactical correct but contains an invalid
 		// point in history, 2010-25-39-84:97 or so
-		throw Xception(format("illegal timestamp in expression: %s") % expr);
+		THROW(format("illegal timestamp in expression: %s") % expr);
 	}
 
 	if (verbose)
@@ -233,16 +222,22 @@ ptime InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose
 		trim(s);
 		if (!comment.empty())
 			s += string(" ; ") + any_cast<string>(comment);
-		cout << (format("    [%s] %s") % lexical_cast<string, ptime>(t) % s).str() << endl;
+		s = (format("    [%s] %s") % lexical_cast<string>(t) % s).str();
+		encoded::cout << s << endl;
 	}
 
 	// now build a data vector for a database insert
+	Database::CollectionsItems temp;
 	if (!comment.empty())
-		items.insert(Database::CollectionsItems::value_type("#", Database::CollectionItem(t, comment)));
+		temp.insert(Database::CollectionsItems::value_type("#", Database::CollectionItem(t, comment)));
 
 	while (regex_search(line, mr, rx_ratio, boost::match_not_dot_newline))
 	{
-		items.insert(Database::CollectionsItems::value_type(mr[2], Database::CollectionItem(t, Ratio(lexical_cast<double>(mr[1]), lexical_cast<double>(mr[3])))));
+		string name(mr[2]);
+		if (collections.find(name) == collections.end())
+			THROW(format("unknown collection: %s") % name);
+
+		temp.insert(Database::CollectionsItems::value_type(name, Database::CollectionItem(t, Ratio(lexical_cast<double>(mr[1]), lexical_cast<double>(mr[3])))));
 		line.erase(mr.position(), mr.length());
 	}
 
@@ -251,23 +246,36 @@ ptime InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose
 		string name(mr[2]);
 		if (name.empty())
 			name = '*';
-		items.insert(Database::CollectionsItems::value_type(name, Database::CollectionItem(t, lexical_cast<double>(mr[1]))));
+		if (collections.find(name) == collections.end())
+			THROW(format("unknown collection: %s") % name);
+
+		temp.insert(Database::CollectionsItems::value_type(name, Database::CollectionItem(t, lexical_cast<double>(mr[1]))));
 		line.erase(mr.position(), mr.length());
 	}
 
 	while (regex_search(line, mr, rx_string, boost::match_not_dot_newline))
 	{
 		string name(mr[2]);
+		if (collections.find(name) == collections.end())
+			THROW(format("unknown collection: %s") % name);
+
 		string value(mr[1]);
 		replace_all(value, "\"\"", "\"");
-		items.insert(Database::CollectionsItems::value_type(name, Database::CollectionItem(t, value)));
+
+		temp.insert(Database::CollectionsItems::value_type(name, Database::CollectionItem(t, value)));
 		line.erase(mr.position(), mr.length());
 	}
 
 	// last check
 	trim(line);
 	if (!line.empty())
-		throw Xception(format("expression contains unrecognized characters: %s") % line);
+		THROW(format("expression contains unrecognized characters: %s") % line);
+
+	// everything went fine, take over the items
+	foreach(const Database::CollectionsItems::value_type& item, temp)
+	{
+		items.insert(item);
+	}
 
 	return t;
 }
@@ -296,7 +304,7 @@ void FileInputImpl::Do (const Config& config, Database& database) const throw (X
 			// get the configured filename from config file
 			const string& f = config.GetStringOption(m_option_key + ".filename");
 			if (f.empty())
-				throw Xception(format("missing specification in configuration file: %s.filename") % m_option_key);
+				THROW(format("missing specification in configuration file: %s.filename") % m_option_key);
 
 			// check if there are wild cards, if so iterate
 			// over the files and fill the filenames vector
@@ -323,7 +331,7 @@ void FileInputImpl::Do (const Config& config, Database& database) const throw (X
 					}
 				}
 				else
-					throw Xception(format("invalid path specification in configuration file: %s.filename") % m_option_key);
+					THROW(format("invalid path specification in configuration file: %s.filename") % m_option_key);
 			}
 			else
 				filenames.push_back(f);
@@ -333,7 +341,6 @@ void FileInputImpl::Do (const Config& config, Database& database) const throw (X
 	}
 
 	// process file by file
-	string msgs;
 	foreach (const string& filename, filenames)
 	{
 		try
@@ -343,11 +350,11 @@ void FileInputImpl::Do (const Config& config, Database& database) const throw (X
 			{
 				ifstream ifs(filename.c_str(), ios::in);
 				if (!ifs.good())
-					throw Xception("file not found");
+					THROW(format("file not found: %s") % filename);
 
 				bool verbose = config.GetBoolOption("verbose");
 				if (verbose)
-					cout << "parsing " << m_vector_key << " file " << filename << endl;
+					encoded::cout << "parsing " << m_vector_key << " file " << filename << endl;
 
 				ProcessFile(config, database, ifs, items);
 			}
@@ -360,14 +367,9 @@ void FileInputImpl::Do (const Config& config, Database& database) const throw (X
 			if (!keep)
 				remove(filename.c_str());
 		}
-		catch (const Xception& e)
+		catch (const Xception& x)
 		{
-			if (!msgs.empty())
-				msgs += '\n';
-			msgs += e.Message() + ", skipping file " + filename;
+			encoded::cerr << x.Message(Xception::complete) << endl;
 		}
 	}
-
-	if (!msgs.empty())
-		throw Xception(msgs);
 }
