@@ -23,8 +23,9 @@ using namespace boost::gregorian;
 using namespace boost::program_options;
 
 #include "../libpdrx/datatypes.h"
+#include "../libpdrx/xception.h"
+#include "../libpdrx/conversions.h"
 #include "../libpdrx/config.h"
-#include "../libpdrx/encoding.h"
 #include "db.h"
 #include "in_impl.h"
 
@@ -91,7 +92,7 @@ CSVFile::CSVFile (const string& option_key)
 				datetime_index = i;
 		}
 		if (datetime_index == (size_t)-1)
-			throw Xception("missing datetime column");
+			THROW("missing datetime column");
 	}
 
 	// this function parses a data line using a given regular expression,
@@ -103,7 +104,7 @@ CSVFile::CSVFile (const string& option_key)
 		regex rx_line(expr);
 		smatch mr;
 		if (!regex_match(line, mr, rx_line))
-			throw Xception("line format error");
+			THROW("line format error");
 
 		// extract the timestamp
 		ptime timestamp(not_a_date_time);
@@ -118,7 +119,7 @@ CSVFile::CSVFile (const string& option_key)
 		}
 		catch (bad_lexical_cast)
 		{
-			throw Xception(format("value error, %s is not a datetime") % s);
+			THROW(format("value error, %s is not a datetime") % s);
 		}
 
 		// extract the data values for the declared collections
@@ -151,7 +152,7 @@ CSVFile::CSVFile (const string& option_key)
 					}
 					catch (bad_lexical_cast)
 					{
-						throw Xception(format("value error, %s is not a double") % s);
+						THROW(format("value error, %s is not a double") % s);
 					}
 					break;
 				}
@@ -163,7 +164,7 @@ CSVFile::CSVFile (const string& option_key)
 					}
 					catch (bad_lexical_cast)
 					{
-						throw Xception(format("value error, %s is not a Ratio") % s);
+						THROW(format("value error, %s is not a Ratio") % s);
 					}
 					break;
 				}
@@ -197,17 +198,17 @@ void CSVFile::ProcessFile (const Config& config, Database& database, ifstream& i
 			evaluate_control_line(ctrl_line, collections, expr, datetime_index);
 			had_ctrl_line = true;
 		}
-		pEncoding = &GetEncoding(config.GetStringOption("encoding"));
+		pEncoding = &NativeEncoding();
 	}
 	else
-		pEncoding = &GetEncoding(config.GetStringOption(m_option_key + ".encoding"));
+		pEncoding = &SpecificEncoding(config.GetStringOption(m_option_key + ".encoding"));
 
 	// parse line by line
 	string line;
 	while (getline(ifs, line).good())
 	{
 		trim(line);
-		line = ConvertFrom(line, *pEncoding);
+		line = Decode(line, *pEncoding);
 
 		// ignore an empty line
 		if (line.empty())
