@@ -22,9 +22,9 @@ using namespace boost::posix_time;
 using namespace boost::gregorian;
 using namespace boost::program_options;
 
-#include "../libpdrx/datatypes.h"
+#include "../libpdrx/xception.h"
+#include "../libpdrx/conversions.h"
 #include "../libpdrx/config.h"
-#include "../libpdrx/encoding.h"
 #include "db.h"
 #include "in_impl.h"
 
@@ -65,7 +65,7 @@ ImapMailClient::ImapMailClient (const string& option_key)
 		charconv_buffer_free(buffer);
 	}
 
-	static void handle_message (mailmessage* pMessage, const string& subject, Database& database, bool verbose, bool keep, bool& data, bool& rejects)
+	static void handle_message (mailmessage* pMessage, const string& subject, Database& database, bool verbose, bool keep, const Database::Collections& collections, bool& data, bool& rejects)
 	{
 		struct mail_flags* pFlags;
 		mailmessage_get_flags(pMessage, &pFlags);
@@ -97,7 +97,18 @@ ImapMailClient::ImapMailClient (const string& option_key)
 					{
 						struct mailimf_date_time& d = *fld_orig_date->dt_date_time;
 						timestamp = ptime(date(d.dt_year, d.dt_month, d.dt_day), time_duration(d.dt_hour, d.dt_min, d.dt_sec,0));
-						InputImpl::LocalizeMailDate(d.dt_zone, timestamp);
+
+						// if needed, convert to UTC
+						if (d.dt_zone != 0)
+						{
+							int diff_hours = d.dt_zone / 100;
+							int diff_min = d.dt_zone - diff_hours * 100;
+							timestamp -= time_duration(diff_hours, diff_min, 0, 0);
+						}
+
+						// now localize
+						typedef boost::date_time::c_local_adjustor<ptime> local_adj;
+						timestamp = local_adj::utc_to_local(timestamp);
 					}
 
 					mailimf_single_fields_free(pImfSingleFields);
@@ -208,11 +219,12 @@ ImapMailClient::ImapMailClient (const string& option_key)
 					{
 						data = true;
 						Database::CollectionsItems items;
-						InputImpl::Parse(line, timestamp, verbose, items);
+						InputImpl::Parse(line, timestamp, verbose, collections, items);
 						database.AddCollectionsItems(items);
 					}
-					catch (const Xception& )
+					catch (const Xception& x)
 					{
+						encoded::cerr << x.Message(Xception::brief) << endl;
 						database.AddRejected(timestamp, line);
 						rejects = true;
 					}
@@ -231,12 +243,12 @@ void ImapMailClient::Do (const Config& config, Database& database) const throw (
 {
 	bool verbose = config.GetBoolOption("verbose");
 	if (verbose)
-		cout << "looking for mail (IMAP)" << endl;
+		encoded::cout << "looking for mail (IMAP)" << endl;
 
 	// get configuration data
 	const string& server = config.GetStringOption(m_option_key + ".server");
 	if (server.empty())
-		throw Xception(format("missing specification in configuration file: %s.server)") % m_option_key);
+		THROW(format("missing specification in configuration file: %s.server)") % m_option_key);
 
 	int port = (config.HasOption(m_option_key + ".port"))
 		? (int)config.GetDoubleOption(m_option_key + ".port")
@@ -244,7 +256,7 @@ void ImapMailClient::Do (const Config& config, Database& database) const throw (
 
 	const string& account = config.GetStringOption(m_option_key + ".account");
 	if (account.empty())
-		throw Xception(format("missing specification in configuration file: %s.account)") % m_option_key);
+		THROW(format("missing specification in configuration file: %s.account)") % m_option_key);
 
 	const string& password = config.GetStringOption(m_option_key + ".password");
 
@@ -262,6 +274,9 @@ void ImapMailClient::Do (const Config& config, Database& database) const throw (
 	bool data = false;
 	bool rejects = false;
 	{
+		Database::Collections collections;
+		database.GetCollections(collections);
+
 		struct mailstorage* pMailStorage = mailstorage_new(NULL);
 		if (imap_mailstorage_init(pMailStorage, server.c_str(), port, NULL, CONNECTION_TYPE_STARTTLS, IMAP_AUTH_TYPE_PLAIN, account.c_str(), password.c_str(), 0, NULL) == 0 &&
 		    mailstorage_connect(pMailStorage) == 0)
@@ -276,7 +291,7 @@ void ImapMailClient::Do (const Config& config, Database& database) const throw (
 					for (size_t i = 0; i < n; i++)
 					{
 						mailmessage* pMessage = (mailmessage*)carray_get(pMailMessagesList->msg_tab, i);
-						handle_message(pMessage, subject, database, verbose, keep, data, rejects);
+						handle_message(pMessage, subject, database, verbose, keep, collections, data, rejects);
 						mailmessage_flush(pMessage);
 					}
 				}
@@ -301,13 +316,13 @@ void ImapMailClient::Do (const Config& config, Database& database) const throw (
 	}
 
 	if (verbose && !data)
-		cout << "    no data on server" << endl;
+		encoded::cout << "    no data on server" << endl;
 
 	if (rejects)
-		throw Xarning("!!! at least one expression has been rejected, try -r to list rejections !!!");
+		encoded::cerr << "!!! at least one expression has been rejected, try -r to list rejections !!!" << endl;
 
 	if (!msg.empty())
-		throw Xception(msg);
+		THROW(msg);
 }
 
 #endif
