@@ -82,7 +82,7 @@ void InputInteractive::Do (const Config& config, Database& database) const throw
 		data_width = 70;	// 10 characters for input on a line
 					// with 80 characters
 
-	encoded::cout << "pdr " << VERSION << ", interactive mode (press ? for help)" << endl;
+	encoded::cout << "pdr " << VERSION << ", interactive mode (press ? for help, q to quit)" << endl;
 
 #ifdef USE_READLINE
 	// disable auto-complete
@@ -145,7 +145,7 @@ void InputInteractive::Do (const Config& config, Database& database) const throw
 		{
 			encoded::cout
 				<< endl
-				<< "type a command to let pdr do some actions, the following commands are available:" << endl
+				<< "type a command (and then RET) to let pdr do some actions, the following commands are available:" << endl
 				<< endl
 				<< "---line navigation---" << endl
 				<< "-                         make the previous line the current line (default)" << endl
