@@ -23,6 +23,7 @@ using namespace boost::gregorian;
 using namespace boost::program_options;
 
 #include "../libpdrx/datatypes.h"
+#include "../libpdrx/xception.h"
 #include "config_impl.h"
 #include "db_impl.h"
 
@@ -36,7 +37,7 @@ Database* DBFactory::Create (const Config& config) throw (Xception)
 {
 	const string& database_type = config.GetStringOption("database.type");
 	if (database_type.empty())
-		throw Xception("missing specification in configuration file: database.type");
+		THROW("missing specification in configuration file: database.type");
 
 	Database* pDatabase = NULL;
 #ifdef USE_SQLITE
@@ -44,7 +45,7 @@ Database* DBFactory::Create (const Config& config) throw (Xception)
 	{
 		const string& database_connect = config.GetFilenameOption("database.connect");
 		if (database_connect.empty())
-			throw Xception("missing specification in configuration file: database.connect");
+			THROW("missing specification in configuration file: database.connect");
 		pDatabase = new SQLiteDatabase(database_connect, config.GetBoolOption("verbose"), config.GetBoolOption("fast"));
 	}
 	else
@@ -54,21 +55,17 @@ Database* DBFactory::Create (const Config& config) throw (Xception)
 	{
 		const string& database_connect = config.GetFilenameOption("database.connect");
 		if (database_connect.empty())
-			throw Xception("missing specification in configuration file: database.connect");
+			THROW("missing specification in configuration file: database.connect");
 		pDatabase = new MySQLDatabase(database_connect, config.GetBoolOption("verbose"), config.GetBoolOption("fast"));
 	}
 	else
 #endif
-	throw Xception(format("invalid database.type specification in configuration file: %s") % database_type);
+	THROW(format("invalid database.type specification in configuration file: %s") % database_type);
 
 	try
 	{
 		pDatabase->Connect();
 		return pDatabase;
 	}
-	catch (...)
-	{
-		delete pDatabase;
-		throw;
-	}
+	CATCH_CLEANUP_RETHROW(delete pDatabase, "could not connect to database");
 }
