@@ -185,7 +185,7 @@ void BoardDiagram::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_uni
 		double left = x_0;
 		double top = CalcY(y_max);
 		const string& yf = FormatY();
-		for (double t = m_ymin; t <= m_ymax; t += m_yunit)
+		for (double t = GetFirstYAxisItem(); t <= m_ymax; t += m_yunit)
 		{
 			double x = x_0 - dash_width;
 			double y = CalcY(t);
@@ -278,7 +278,7 @@ void BoardDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_ma
 		double left = x_0;
 		double top = CalcY(y_max);
 		const string& yf = FormatY();
-		for (double t = m_ymin; t <= m_ymax; t += m_yunit)
+		for (double t = GetFirstYAxisItem(); t <= m_ymax; t += m_yunit)
 		{
 			double x = x_0 - dash_width;
 			double y = CalcY(t);
@@ -606,6 +606,9 @@ void BoardDiagram::DrawHLine (double value, RGB color, double thickness)
 {
 	try
 	{
+		if (value < m_ymin || value > m_ymax)
+			return;
+
 		double y = CalcY(value);
 		m_shapes << Line(CalcX(m_xmin), y, m_diagram.width, y, COLOR(color), (float)((thickness == 0.0) ? LINE_THICKNESS : (thickness / 2.0)));
 	}
