@@ -290,7 +290,7 @@ void CairoDiagram::DrawAxes (const ptime& x_min, const ptime& x_max, XUnit x_uni
 		const double dash_width = m_diagram.width / 100.0; // one percent of m_width
 
 		const string& yf = FormatY();
-		for (double t = m_ymin; t <= m_ymax; t += m_yunit)
+		for (double t = GetFirstYAxisItem(); t <= m_ymax; t += m_yunit)
 		{
 			double y = CalcY(t);
 			move_to(x_0 - dash_width, y);
@@ -378,7 +378,7 @@ void CairoDiagram::DrawAxes (Diagram::FoldInterval fi, double y_min, double y_ma
 		const double dash_width = m_diagram.width / 100.0; // one percent of m_width
 
 		const string& yf = FormatY();
-		for (double t = m_ymin; t <= m_ymax; t += m_yunit)
+		for (double t = GetFirstYAxisItem(); t <= m_ymax; t += m_yunit)
 		{
 			double y = CalcY(t);
 			move_to(x_0 - dash_width, y);
@@ -643,6 +643,9 @@ void CairoDiagram::DrawHLine (double value, RGB color, double thickness)
 {
 	try
 	{
+		if (value < m_ymin || value > m_ymax)
+			return;
+
 		cairo_set_source_rgb(m_pContext, RED(color), GREEN(color), BLUE(color));
 		cairo_set_line_width(m_pContext, (float)((thickness == 0.0) ? m_thickness : thickness));
 		double x_0 = CalcX(m_xmin);
