@@ -23,6 +23,8 @@ using namespace boost::gregorian;
 using namespace boost::program_options;
 
 #include "../libpdrx/datatypes.h"
+#include "../libpdrx/xception.h"
+#include "../libpdrx/conversions.h"
 #include "config_impl.h"
 #include "db.h"
 #include "out_impl.h"
@@ -338,7 +340,7 @@ FTree* OutputImpl::Parse (const string& input) throw (Xception)
 		}
 
 		if (right.empty())
-			throw Xception("unexpected end of input");
+			THROW("unexpected end of input");
 		else
 		{
 			stringstream ss;
@@ -347,7 +349,7 @@ FTree* OutputImpl::Parse (const string& input) throw (Xception)
 			if (left.length() > 5)
 				ss << string(left.length() - 5, ' ');
 			ss << "---> " << right;
-			throw Xception(ss.str());
+			THROW(ss.str());
 		}
 	}
 
